@@ -190,9 +190,9 @@ class Users(object):
 			if not r3sponse.success(response): raise ValueError(response["error"])
 			users = []
 			emails = response["collection"]
-			for email in emails:
-				users.append(auth.get_user_by_email(email))
-			return users
+			#for email in emails:
+			#	users.append(auth.get_user_by_email(email))
+			return email
 		else:
 			return auth.list_users().iterate_all()
 	def verify_id_token(self, id_token):
